@@ -4,46 +4,38 @@ use rand::{thread_rng, Rng};
 use std::env;
 use std::iter;
 
-#[cfg(not(windows))]
-use users::get_current_username;
-
 #[cfg(windows)]
-fn get_additional_temp_path() -> Option<String> {
-    None
+fn get_extra_path() -> Option<String> {
+    let name = env!("CARGO_PKG_NAME").to_string();
+    Some(name)
 }
 
 #[cfg(not(windows))]
-fn get_additional_temp_path() -> Option<String> {
-    let username = get_current_username();
+fn get_extra_path() -> Option<String> {
+    None
+}
 
-    match username {
-        Some(os_value) => match os_value.into_string() {
-            Ok(value) => Some(value),
-            Err(_) => None,
-        },
-        None => None,
-    }
+fn get_random_string() -> String {
+    let mut rng = thread_rng();
+    iter::repeat(())
+        .map(|()| rng.sample(Alphanumeric))
+        .map(char::from)
+        .take(10)
+        .collect()
 }
 
 pub(crate) fn get(extension: &str) -> String {
     let name = env!("CARGO_PKG_NAME");
-
-    let mut rng = thread_rng();
-    let file_name: String = iter::repeat(())
-        .map(|()| rng.sample(Alphanumeric))
-        .map(char::from)
-        .take(10)
-        .collect();
+    let mut file_name = get_random_string();
+    file_name.insert(0, '_');
+    file_name.insert_str(0, name);
 
     let mut file_path = env::temp_dir();
 
-    match get_additional_temp_path() {
-        Some(additional_path) => file_path.push(additional_path),
-        None => {}
+    if let Some(extra_path) = get_extra_path() {
+        file_path.push(extra_path);
     };
 
-    file_path.push(name);
-
     file_path.push(file_name);
     file_path.set_extension(extension);
 
